__all__ = ['style_similarity', 'structural_similarity', 'similarity']


from html_similarity.style_similarity import style_similarity
from html_similarity.structural_similarity import structural_similarity
from html_similarity.similarity import similarity
